import  {
  select,
  json,
  tree,
  hierarchy,
  linkHorizontal,
  zoom,
  event
} from 'd3';

const width = document.body.clientWidth;
const height = document.body.clientHeight;
const margin = {
  top:	30,
  left:	100,
  right:	60,
  bottom:	30
}
const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;
const svg = select("svg");
svg
  	.attr("width", width)
		.attr("height", height);

// setting up zoom
const g = svg.append("g")
		.attr("transform", `translate(${margin.left},${margin.top})`);

svg.call(zoom().on("zoom", () => g.attr("transform", event.transform)));

const treeLayout = tree()
	.size([innerHeight, innerWidth]);

json("data.json")
	.then(data => {
  	const root = hierarchy(data);
  	const links = treeLayout(root).links();
  	const linkPathGenerator = linkHorizontal()
    		.x(d => d.y)
    		.y(d => d.x);

  	g.selectAll("path").data(links)
  		.enter().append('path')
  			.attr("class", "dendron")
  			.attr('d', linkPathGenerator);
  
  	g.selectAll("text").data(root.descendants())
  		.enter().append("text")
  			.attr("class", "dendron-label")
  			.attr("x", d => d.y)
  			.attr("y", d => d.x)
  			.text(d => d.data.data.id)
  			.attr("font-size", d => 3.2 - d.depth + 'em')
  			.attr("text-anchor", d => d.children ? "middle" : "start");
	});